==> web-10.0.0.tgz: package/lib/myTable/treeTable/ParTree.js <==
import * as React from "react";
import TrItem from "./TrItem";
import { SlideBox } from "../../animate/index";
class ParTree extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.slideCallback = (isStart) => {
            if (!isStart) {
                this.props.scrollInit();
            }
        };
    }
    createColgroup() {
        const { cols } = this.props;
        const arr = cols.map((val) => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return React.createElement("col", { style: style, key: field });
        });
        return React.createElement("colgroup", null, arr);
    }
    getSubBody() {
        const { node, fixObj, fixObj: { childField, idField }, cols, lev, isMainView, index, changeState, order, scrollInit } = this.props;
        const arr = node.get(childField);
        return arr.map((val, oindex) => {
            const children = val.get(childField);
            const id = val.get(idField);
            if (children && children.size) {
                return (React.createElement(ParTree, { order: order, key: id, node: val, scrollInit: scrollInit, index: `${index},${oindex}`, lev: lev + 1, changeState: changeState, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, order: order, lev: lev + 1, node: val, index: `${index},${oindex}`, changeState: changeState, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
        });
    }
    render() {
        const { cols, fixObj, node, lev, isMainView, index, changeState, order } = this.props;
        const colgroup = this.createColgroup();
        const expand = node.get("expand");
        return (React.createElement(React.Fragment, null,
            React.createElement(TrItem, { node: node, fixObj: fixObj, cols: cols, lev: lev, order: order, changeState: changeState, index: index, isMainView: isMainView, isPar: true }),
            React.createElement("tr", { className: "tree-td" },
                React.createElement("td", { colSpan: cols.length },
                    React.createElement(SlideBox, { slide: expand, slideFnCallback: this.slideCallback },
                        React.createElement("div", { className: "tab-body" },
                            React.createElement("table", null,
                                colgroup,
                                React.createElement("tbody", null, this.getSubBody()))))))));
    }
}
export default ParTree;

==> web-10.1.0.tgz: package/lib/myTable/treeTable/ParTree.js <==
import * as React from "react";
import TrItem from "./TrItem";
import { SlideBox } from "../../animate/index";
class ParTree extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.slideCallback = (isStart) => {
            if (!isStart) {
                this.props.scrollInit();
            }
        };
    }
    createColgroup() {
        const { cols } = this.props;
        const arr = cols.map((val) => {
            const { width, field } = val;
            const style = width ? { width } : undefined;
            return React.createElement("col", { style: style, key: field });
        });
        return React.createElement("colgroup", null, arr);
    }
    getSubBody() {
        const { node, fixObj, fixObj: { childField, idField }, cols, lev, isMainView, index, changeState, scrollInit } = this.props;
        const arr = node.get(childField);
        return arr.map((val, oindex) => {
            const children = val.get(childField);
            const id = val.get(idField);
            if (children && children.size) {
                return (React.createElement(ParTree, { key: id, node: val, scrollInit: scrollInit, index: `${index},${oindex}`, lev: lev + 1, changeState: changeState, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
            else {
                return (React.createElement(TrItem, { key: id, lev: lev + 1, node: val, index: `${index},${oindex}`, changeState: changeState, cols: cols, isMainView: isMainView, fixObj: fixObj }));
            }
        });
    }
    render() {
        const { cols, fixObj, node, lev, isMainView, index, changeState } = this.props;
        const colgroup = this.createColgroup();
        const expand = node.get("expand");
        return (React.createElement(React.Fragment, null,
            React.createElement(TrItem, { node: node, fixObj: fixObj, cols: cols, lev: lev, changeState: changeState, index: index, isMainView: isMainView, isPar: true }),
            React.createElement("tr", { className: "tree-td" },
                React.createElement("td", { colSpan: cols.length },
                    React.createElement(SlideBox, { slide: expand, slideFnCallback: this.slideCallback },
                        React.createElement("div", { className: "tab-body" },
                            React.createElement("table", null,
                                colgroup,
                                React.createElement("tbody", null, this.getSubBody()))))))));
    }
}
export default ParTree;
